# Seq2Seq Agent

The Seq2Seq agent takes an input sequence and produces an output sequence.

The agent supports encoding and decoding via a variety of RNN flavors,
including LSTMs and GRUs. The agent supports encoding and decoding via a
variety of RNN flavors, including LSTMs and GRUs. It also supports numerous
decoding strategies, like beam search and nucleus decoding.

The following papers outline more information regarding this model:
  - Neural Machine Translation by Jointly Learning to Align and Translate
    [(Bahdanau et al. 2014)](https://arxiv.org/abs/1409.0473)
  - Sequence to Sequence Learning with Neural Networks
    [(Sutskever et al. 2014)](https://arxiv.org/abs/1409.3215)
  - Effective Approaches to Attention-based Neural Machine Translation
    [(Luong et al. 2015)](https://arxiv.org/abs/1508.04025)
